\name{ceil}
\alias{ceil}
\title{MATLAB ceil function}
\description{
  Rounds to the nearest integer.
}
\usage{
ceil(x)
}
\arguments{
  \item{x}{numeric to be rounded}
}
\details{
   Simply invokes \code{base::ceiling} for those more used to C library API
name.
}
\value{
   Returns \code{vector} containing smallest integers not less than the
   corresponding elements of argument \code{x}.
}
\examples{
ceil(c(0.9, 1.3, 2.4))
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{eye}
\alias{eye}
\title{MATLAB eye function}
\description{
  Create an identity matrix.
}
\usage{
eye(n, m = n)
}
\arguments{
  \item{n, m}{dimensions for the result}
}
\value{
   Returns \code{matrix} of order 1.
   Defaults to square if second dimension argument \code{m} not provided.
}
\examples{
eye(3)
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{find}
\alias{find}
\title{MATLAB find function}
\description{
  Finds indices of elements.
}
\usage{
find(x)
}
\arguments{
  \item{x}{expression to evaluate}
}
\details{
   If expression is not logical, finds indices of nonzero elements of
argument \code{x}.
}
\value{
   Returns indices of corresponding elements matching the expression \code{x}.
}
\examples{
find(-3:3 >= 0)
find(c(0, 1, 0, 2, 3))
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{fix}
\alias{fix}
\title{MATLAB fix function}
\description{
  Rounds toward zero.
}
\usage{
fix(A)
}
\arguments{
  \item{A}{numeric to be rounded}
}
\details{
   Simply invokes \code{base::trunc}.
}
\value{
   Returns \code{vector} containing integers by truncating the
   corresponding values of argument \code{A} toward zero.
}
\examples{
fix(c(1.3, 2.5, 3.7))
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{fliplr}
\alias{fliplr}
\alias{fliplr,ANY-method}
\alias{fliplr,array-method}
\alias{fliplr,matrix-method}
\alias{fliplr,missing-method}
\alias{fliplr,vector-method}
\alias{flipud}
\alias{flipud,ANY-method}
\alias{flipud,array-method}
\alias{flipud,matrix-method}
\alias{flipud,missing-method}
\alias{flipud,vector-method}
\title{MATLAB matrix flip functions}
\description{
  Flips matrices either left-right or up-down.
}
\usage{
fliplr(object)
flipud(object)
}
\arguments{
  \item{object}{vector or matrix to be flipped}
}
\details{
   These are S4 generic functions.
}
\value{
   Return value is the same type as argument \code{object}.
}
\examples{
fliplr(1:9)
flipud(1:9)		# same as previous since vectors have no orientation in R
fliplr(matrix(1:9, 3, 3, byrow = TRUE))
flipud(matrix(1:9, 3, 3, byrow = TRUE))
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{MATLAB}
\alias{matlab}
\title{MATLAB replacement functions}
\description{
  Wrapper functions and variables used to replicate MATLAB
function calls as best possible to simplify porting.
}
\details{
   They are no more complete than absolutely necessary and are quite
possibly broken for fringe cases.
}
\note{
   In certain cases, these may not correspond exactly with MATLAB API
as sometimes it just wasn't possible.
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{mod}
\alias{mod}
\alias{rem}
\title{MATLAB mod/rem functions}
\description{
  Provides modulus and remainder after division.
}
\usage{
mod(x, y)
rem(x, y)
}
\arguments{
  \item{x, y}{numeric vectors or objects}
}
\value{
   Returns \code{vector} containing result of the element by element operations.
}
\examples{
# same results with x, y having the same sign
mod(5, 3)
rem(5, 3)
# same results with x, y having different signs
mod(-5, 3)
rem(-5, 3)
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{ones}
\alias{ones}
\alias{zeros}
\title{MATLAB ones/zeros functions}
\description{
  Create a matrix consisting of all ones or zeros.
}
\usage{
ones(n, m = n)
zeros(n, m = n)
}
\arguments{
  \item{n, m}{dimensions for the result}
}
\value{
   Returns \code{matrix} consisting only of ones (or zeros).
   Defaults to square if second dimension argument \code{m} not provided.
}
\examples{
ones(3)
zeros(3)
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{repmat}
\alias{repmat}
\title{MATLAB repmat function}
\description{
  Replicate and tile a matrix.
}
\usage{
repmat(A, m, n = if (length(m) == 1)m)
}
\arguments{
  \item{A}{numeric vector or matrix to be tiled}
  \item{n, m}{dimensions for the result}
}
\value{
   Returns \code{matrix} with value \code{A} tiled to the number of dimensions
specified.
   Defaults to square if second dimension argument \code{n} not provided.
}
\examples{
repmat(1, 3)	# same as ones(3)
repmat(matrix(1:4, 2, 2), 3)
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{rot90}
\alias{rot90}
\title{MATLAB rot90 function}
\description{
  Rotates matrix counterclockwise \code{k*90} degrees.
}
\usage{
rot90(A, k = 1)
}
\arguments{
  \item{A}{matrix to be rotated}
  \item{k}{integer specifying the number of times to rotate (1..4)}
}
\details{
   Rotating 4 times (360 degrees) returns the original matrix unchanged.
}
\value{
   Returns \code{matrix} corresponding to argument \code{A} having been rotated
   argument \code{k} number of times.
}
\examples{
rot90(matrix(1:4, 2, 2))
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{size}
\alias{size}
\title{MATLAB size function}
\description{
  Provides dimensions of \code{x}.
}
\usage{
size(x)
}
\arguments{
  \item{x}{numeric vector or matrix}
}
\details{
   Invokes \code{base::length} or \code{base::dim} depending on argument \code{x}.
}
\value{
   Returns class \code{size_t} containing the dimensions of input argument.
}
\examples{
size(1:8)
size(matrix(1:8, 2, 4))
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{std}
\alias{std}
\title{MATLAB std function}
\description{
  Computes the standard deviation of the values of \code{x}.
}
\usage{
std(x, flag = 0)
}
\arguments{
  \item{x}{numeric vector or matrix}
  \item{flag}{integer logical. If \code{0}, selects unbiased algorithm.
If \code{1}, selects biased algorithm (currently unsupported).}
}
\details{
   Simply invokes \code{stats::sd}.
}
\value{
   Return value depends on argument \code{x}. If \code{vector}, returns
   the standard deviation. If \code{matrix}, returns vector containing
   the standard deviation of each column.
}
\examples{
std(1:2) ^ 2
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{sum}
\alias{sum}
\alias{sum,ANY-method}
\alias{sum,array,logical-method}
\alias{sum,array,missing-method}
\alias{sum,logical-method}
\alias{sum,matrix,logical-method}
\alias{sum,matrix,missing-method}
\alias{sum,missing-method}
\alias{sum,vector,logical-method}
\alias{sum,vector,missing-method}
\title{MATLAB sum function}
\description{
  Provides sum of elements.
}
\usage{
sum(x, na.rm = FALSE)
}
\arguments{
  \item{x}{numeric to be summed}
  \item{na.rm}{logical. If \code{TRUE}, remove missing values}
}
\details{
   This is an S4 generic function.
}
\value{
   Return value depends on argument \code{x}. If \code{vector}, returns
   the same as \code{base::sum}. If \code{matrix}, returns vector containing
   the sum of each column.
}
\examples{
sum(1:9)
sum(matrix(1:9, 3, 3))
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
\name{tictoc}
\alias{tic}
\alias{toc}
\title{MATLAB timer functions}
\description{
  Provides stopwatch timer. Function \code{tic} starts the timer and \code{toc}
displays the elapsed time since the timer was started. 
}
\usage{
tic(gcFirst = FALSE)
toc()
}
\arguments{
  \item{gcFirst}{logical. If \code{TRUE}, perform garbage collection prior
to starting stopwatch}
}
\details{
   Provides analog to \code{base::system.time}. Function \code{toc} can be
invoked multiple times in a row.
}
\examples{
tic()
for(i in 1:100) mad(runif(1000))	# kill time
toc()
}
\author{P. Roebuck, \email{roebuck@mdanderson.org}}
\keyword{interface}


\eof
